//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/SphericalDetectorEditor.cpp
//! @brief     Implement class SphericalDetectorEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/SphericalDetectorEditor.h"
#include "GUI/Model/Item/SphericalDetectorItem.h"
#include "GUI/View/Instrument/ResolutionFunctionEditor.h"
#include "GUI/View/Instrument/SphericalAxisEditor.h"

#include <QGridLayout>

SphericalDetectorEditor::SphericalDetectorEditor(QWidget* parent, SphericalDetectorItem* item)
    : QWidget(parent)
{
    ASSERT(item);
    auto* grid = new QGridLayout(this);
    grid->setColumnStretch(0, 1);
    grid->setColumnStretch(1, 1);
    grid->setColumnStretch(2, 1);

    auto* phiAxisEditor = new SphericalAxisEditor(u8"\u03c6 axis", this, item->phiAxisItem());
    grid->addWidget(phiAxisEditor, 1, 0);

    auto* alphaAxisEditor = new SphericalAxisEditor(u8"\u03b1 axis", this, item->alphaAxisItem());
    grid->addWidget(alphaAxisEditor, 1, 1);

    auto* resolutionFunctionEditor =
        new ResolutionFunctionEditor(ResolutionFunctionEditor::Degree, this, item);
    grid->addWidget(resolutionFunctionEditor, 1, 2);

    grid->setRowStretch(2, 1);

    connect(phiAxisEditor, &SphericalAxisEditor::dataChanged, this,
            &SphericalDetectorEditor::dataChanged);

    connect(alphaAxisEditor, &SphericalAxisEditor::dataChanged, this,
            &SphericalDetectorEditor::dataChanged);

    connect(resolutionFunctionEditor, &ResolutionFunctionEditor::dataChanged, this,
            &SphericalDetectorEditor::dataChanged);
}
